==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/SCCCollapser.h <==
// public class soot.jimple.spark.solver.SCCCollapser

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 981ec81bc6331781 soot_jimple_spark_solver_SCCCollapser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_SCCCollapser_H_
#define _JC_soot_jimple_spark_solver_SCCCollapser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_internal_TypeManager$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs	_jc_soot_jimple_spark_solver_SCCCollapser$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs	_jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$refs	_jc_soot_jimple_spark_solver_SCCCollapser$refs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$nonrefs	_jc_soot_jimple_spark_solver_SCCCollapser$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$object	_jc_soot_jimple_spark_solver_SCCCollapser$object;

typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vmethods	_jc_soot_jimple_spark_solver_SCCCollapser$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vtable	_jc_soot_jimple_spark_solver_SCCCollapser$vtable;
typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vtype	_jc_soot_jimple_spark_solver_SCCCollapser$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$_init$f122f46e77bbb54d(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, jboolean);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$collapse$485220070cfa5581(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *);
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$dfsVisit$39b178b32cd35c3d(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_SCCCollapser$method_info$collapse$485220070cfa5581;
extern _jc_method _jc_soot_jimple_spark_solver_SCCCollapser$method_info$dfsVisit$39b178b32cd35c3d;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_SCCCollapser$vmethods {
	void	(*collapse$485220070cfa5581)(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *);
	void	(*dfsVisit$39b178b32cd35c3d)(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_SCCCollapser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_SCCCollapser$vmethods	soot_jimple_spark_solver_SCCCollapser;
};

// Vtype
struct _jc_soot_jimple_spark_solver_SCCCollapser$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_SCCCollapser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_util_HashSet$object	*visited;
	struct _jc_soot_jimple_spark_internal_TypeManager$object	*typeManager;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_SCCCollapser$refs {
    _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs	soot_jimple_spark_solver_SCCCollapser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs {
	jint	numCollapsed;
	jboolean	ignoreTypes;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_SCCCollapser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs	soot_jimple_spark_solver_SCCCollapser;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_SCCCollapser$object {
	_jc_soot_jimple_spark_solver_SCCCollapser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_SCCCollapser$vtype	*vtype;
	_jc_soot_jimple_spark_solver_SCCCollapser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_SCCCollapser$vtype _jc_soot_jimple_spark_solver_SCCCollapser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_SCCCollapser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_SCCCollapser$class_object;

#endif	/* _JC_soot_jimple_spark_solver_SCCCollapser_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/SCCCollapser.h <==
// public class soot.jimple.spark.solver.SCCCollapser

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 981ec81bc6331781 soot_jimple_spark_solver_SCCCollapser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_SCCCollapser_H_
#define _JC_soot_jimple_spark_solver_SCCCollapser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_internal_TypeManager$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs	_jc_soot_jimple_spark_solver_SCCCollapser$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs	_jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$refs	_jc_soot_jimple_spark_solver_SCCCollapser$refs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$nonrefs	_jc_soot_jimple_spark_solver_SCCCollapser$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_SCCCollapser$object	_jc_soot_jimple_spark_solver_SCCCollapser$object;

typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vmethods	_jc_soot_jimple_spark_solver_SCCCollapser$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vtable	_jc_soot_jimple_spark_solver_SCCCollapser$vtable;
typedef const struct _jc_soot_jimple_spark_solver_SCCCollapser$vtype	_jc_soot_jimple_spark_solver_SCCCollapser$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$_init$f122f46e77bbb54d(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$collapse$485220070cfa5581(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_SCCCollapser$method$dfsVisit$39b178b32cd35c3d(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_SCCCollapser$method_info$collapse$485220070cfa5581;
extern _jc_method _jc_soot_jimple_spark_solver_SCCCollapser$method_info$dfsVisit$39b178b32cd35c3d;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_SCCCollapser$vmethods {
	void	(*collapse$485220070cfa5581)(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *) _JC_JCNI_ATTR;
	void	(*dfsVisit$39b178b32cd35c3d)(_jc_env *, struct _jc_soot_jimple_spark_solver_SCCCollapser$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_SCCCollapser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_SCCCollapser$vmethods	soot_jimple_spark_solver_SCCCollapser;
};

// Vtype
struct _jc_soot_jimple_spark_solver_SCCCollapser$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_SCCCollapser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_util_HashSet$object	*visited;
	struct _jc_soot_jimple_spark_internal_TypeManager$object	*typeManager;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_SCCCollapser$refs {
    _jc_soot_jimple_spark_solver_SCCCollapser$sub_refs	soot_jimple_spark_solver_SCCCollapser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs {
	jint	numCollapsed;
	jboolean	ignoreTypes;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_SCCCollapser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_SCCCollapser$sub_nonrefs	soot_jimple_spark_solver_SCCCollapser;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_SCCCollapser$object {
	_jc_soot_jimple_spark_solver_SCCCollapser$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_SCCCollapser$vtype	*vtype;
	_jc_soot_jimple_spark_solver_SCCCollapser$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_SCCCollapser$vtype _jc_soot_jimple_spark_solver_SCCCollapser$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_SCCCollapser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_SCCCollapser$class_object;

#endif	/* _JC_soot_jimple_spark_solver_SCCCollapser_H_ */
